@@ -2,7 +2,9 @@
 """
 import os
 import shutil
+import yaml
 
+from libzet.Attributes import Attributes
 from libzet.util.edit import edit
 from libzet.parsing import str_to_zettels, zettels_to_str
 from libzet.Zettel import Zettel
@@ -11,7 +13,7 @@ from libzet.Zettel import Zettel
 def create_zettel(
         path,
         text='', title='', headings=None, attrs=None, zettel_format='md',
-        no_edit=False, errlog=''):
+        no_edit=False, errlog='', template=None):
     """ Create and new zettel on disk and edit it.
 
     Args:
@@ -22,6 +24,12 @@ def create_zettel(
         zettel_format: 'md' or 'rst'
         errlog: See edit_zettels
         no_edit: Set to True to skip editing.
+        template: Optionally init the new zettel from a template. May be
+            a path to a yaml file or a dict. Defaults to ztemplate.yaml
+            within the same dir as the new zettel.
+
+            If template exists then the headings and attrs from that
+            file will be used to init the zettel.
 
     Returns:
         The new zettel reference.
@@ -33,6 +41,27 @@ def create_zettel(
     if os.path.exists(path):
         raise FileExistsError(f'Already a Zettel at {path}')
 
+    if template is None:
+        dir_ = os.path.dirname(path) or '.'
+        template = template or f'{dir_}/ztemplate.yaml'
+
+    if type(template) is str:
+        if os.path.exists(template):
+            with open(template) as f:
+                template = yaml.safe_load(f.read())
+        else:
+            template = {}
+
+    template = template or {}
+    template = Attributes(template)
+
+    # Set defaults from template
+    if 'headings' in template and not headings:
+        headings = {k: '' for k in template['headings']}
+
+    if 'attrs' in template and not attrs:
+        attrs = template['attrs']
+
     z = None
     if text:
         z = str_to_zettels(text, zettel_format)[0]
